**WORK IN PROGRESS**

PySecretHandshake - Secret Handshake in Python
==============================================


|build-status| |code-coverage|

This module implements Secret Handshake as specified in Dominc Tarr's paper `"Designing a Secret Handshake: Authenticated
Key Exchange as a Capability System" <http://dominictarr.github.io/secret-handshake-paper/shs.pdf>`_ (Dominic Tarr, 2015).

**Please, don't use this package in production. The implementation hasn't yet been carefully checked.**

.. |build-status| image:: https://travis-ci.org/pferreir/PySecretHandshake.svg?branch=master
                   :alt: Travis Build Status
                   :target: https://travis-ci.org/pferreir/PySecretHandshake
.. |code-coverage| image:: https://coveralls.io/repos/github/pferreir/PySecretHandshake/badge.svg?branch=master
                   :alt: Code Coverage
                   :target: https://coveralls.io/github/pferreir/PySecretHandshake?branch=master
